@@ -7,6 +7,8 @@ function(org,showurl=FALSE,smt=FALSE,sme=FALSE)
    URLdef<-ncbi2r.options()
    getURL<-paste(URLdef$front,"esearch.fcgi?db=taxonomy&term=",org,URLdef$back,sep="")
    webget<-get.file(getURL,showurl,clean=FALSE)
-   taxid<-as.numeric(getListFromXML(webget,sme=sme,smt=smt)) 
+   taxid<-try(as.numeric(getListFromXML(webget,sme=sme,smt=smt)))
+   if(class(taxid)=="try-error")
+     stop("NCBI2R Error GT-001. GetTax function failed to identify organism.")
    return(taxid=taxid)
    }    
